<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://makewebbetter.com/
 * @since             1.0.0
 * @package           Mwb_Multi_Currency_Switcher_For_Woocommerce
 *
 * @wordpress-plugin
 * Plugin Name:       MWB Multi Currency Switcher For WooCommerce
 * Plugin URI:        https://wordpress.org/plugins/mwb-multi-currency-switcher-for-woocommerce/
 * Description:       MWB Multi Currency Switcher For WooCommerce is used to allow your site visitors to switch product price into different currencies.
 * Version:           1.1.0
 * Author:            MakeWebBetter
 * Author URI:        https://makewebbetter.com/
 * Text Domain:       mwb-multi-currency-switcher-for-woocommerce
 * Domain Path:       /languages
 *
 * Requires at least: 5.0
 * Tested up to:      5.8
 * WC requires at least: 4.0
 * WC tested up to:   5.5.2
 *
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	die;
}
// To Activate plugin only when WooCommerce is active.
$activated = false;

// Check if WooCommerce is active.
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {

	$activated = true;
}
if ( $activated ) {
	/**
	 * Define plugin constants.
	 *
	 * @since             1.0.0
	 */
	function define_mwb_multi_currency_switcher_for_woocommerce_constants() {

		mwb_multi_currency_switcher_for_woocommerce_constants( 'MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_VERSION', '1.1.0' );
		mwb_multi_currency_switcher_for_woocommerce_constants( 'MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_DIR_PATH', plugin_dir_path( __FILE__ ) );
		mwb_multi_currency_switcher_for_woocommerce_constants( 'MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_DIR_URL', plugin_dir_url( __FILE__ ) );
		mwb_multi_currency_switcher_for_woocommerce_constants( 'MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_SERVER_URL', 'https://makewebbetter.com' );
		mwb_multi_currency_switcher_for_woocommerce_constants( 'MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_ITEM_REFERENCE', 'MWB Multi Currency Switcher for WooCommerce' );
	}


	/**
	 * Callable function for defining plugin constants.
	 *
	 * @param   String $key    Key for contant.
	 * @param   String $value   value for contant.
	 * @since             1.0.0
	 */
	function mwb_multi_currency_switcher_for_woocommerce_constants( $key, $value ) {

		if ( ! defined( $key ) ) {
			define( $key, $value );
		}
	}

	/**
	 * The code that runs during plugin activation.
	 * This action is documented in includes/class-mwb-multi-currency-switcher-for-woocommerce-activator.php
	 */
	function activate_mwb_multi_currency_switcher_for_woocommerce() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-mwb-multi-currency-switcher-for-woocommerce-activator.php';
		Mwb_Multi_Currency_Switcher_For_Woocommerce_Activator::mwb_multi_currency_switcher_for_woocommerce_activate();
		$mwb_mmcsfw_active_plugin = get_option( 'mwb_all_plugins_active', false );
		if ( is_array( $mwb_mmcsfw_active_plugin ) && ! empty( $mwb_mmcsfw_active_plugin ) ) {
			$mwb_mmcsfw_active_plugin['mwb-multi-currency-switcher-for-woocommerce'] = array(
				'plugin_name' => __( 'MWB Multi Currency Switcher For WooCommerce', 'mwb-multi-currency-switcher-for-woocommerce' ),
				'active'      => '1',
			);
		} else {
			$mwb_mmcsfw_active_plugin = array();
			$mwb_mmcsfw_active_plugin['mwb-multi-currency-switcher-for-woocommerce'] = array(
				'plugin_name' => __( 'MWB Multi Currency Switcher For WooCommerce', 'mwb-multi-currency-switcher-for-woocommerce' ),
				'active'      => '1',
			);
		}
		update_option( 'mwb_all_plugins_active', $mwb_mmcsfw_active_plugin );
	}

	/**
	 * The code that runs during plugin deactivation.
	 * This action is documented in includes/class-mwb-multi-currency-switcher-for-woocommerce-deactivator.php
	 */
	function deactivate_mwb_multi_currency_switcher_for_woocommerce() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-mwb-multi-currency-switcher-for-woocommerce-deactivator.php';
		Mwb_Multi_Currency_Switcher_For_Woocommerce_Deactivator::mwb_multi_currency_switcher_for_woocommerce_deactivate();
		$mwb_mmcsfw_deactive_plugin = get_option( 'mwb_all_plugins_active', false );
		if ( is_array( $mwb_mmcsfw_deactive_plugin ) && ! empty( $mwb_mmcsfw_deactive_plugin ) ) {
			foreach ( $mwb_mmcsfw_deactive_plugin as $mwb_mmcsfw_deactive_key => $mwb_mmcsfw_deactive ) {
				if ( 'mwb-multi-currency-switcher-for-woocommerce' === $mwb_mmcsfw_deactive_key ) {
					$mwb_mmcsfw_deactive_plugin[ $mwb_mmcsfw_deactive_key ]['active'] = '0';
				}
			}
		}
		update_option( 'mwb_all_plugins_active', $mwb_mmcsfw_deactive_plugin );
	}

	register_activation_hook( __FILE__, 'activate_mwb_multi_currency_switcher_for_woocommerce' );
	register_deactivation_hook( __FILE__, 'deactivate_mwb_multi_currency_switcher_for_woocommerce' );

	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/class-mwb-multi-currency-switcher-for-woocommerce.php';


	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function run_mwb_multi_currency_switcher_for_woocommerce() {
		define_mwb_multi_currency_switcher_for_woocommerce_constants();

		$mwb_mmcsfw_plugin_standard = new Mwb_Multi_Currency_Switcher_For_Woocommerce();
		$mwb_mmcsfw_plugin_standard->mwb_mmcsfw_run();
		$GLOBALS['mwb_mmcsfw_obj'] = $mwb_mmcsfw_plugin_standard;

	}
	run_mwb_multi_currency_switcher_for_woocommerce();


	// Add settings link on plugin page.
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'mwb_multi_currency_switcher_for_woocommerce_settings_link' );

	/**
	 * Settings link.
	 *
	 * @since    1.0.0
	 * @param   Array $links    Settings link array.
	 */
	function mwb_multi_currency_switcher_for_woocommerce_settings_link( $links ) {

		$my_link = array(
			'<a href="' . admin_url( 'admin.php?page=mwb_multi_currency_switcher_for_woocommerce_menu' ) . '">' . __( 'Settings', 'mwb-multi-currency-switcher-for-woocommerce' ) . '</a>',
		);
		return array_merge( $my_link, $links );
	}

	/**
	 * Adding custom setting links at the plugin activation list.
	 *
	 * @param array  $links_array array containing the links to plugin.
	 * @param string $plugin_file_name plugin file name.
	 * @return array
	 */
	function mwb_multi_currency_switcher_for_woocommerce_custom_settings_at_plugin_tab( $links_array, $plugin_file_name ) {
		if ( strpos( $plugin_file_name, basename( __FILE__ ) ) ) {
			$links_array[] = '<a href="https://demo.makewebbetter.com/mwb-multi-currency-switcher-for-woocommerce" target="_blank"><img src="' . esc_html( MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_DIR_URL ) . 'admin/image/Demo.svg" class="mwb-info-img" alt="Demo image">' . __( 'Demo', 'mwb-multi-currency-switcher-for-woocommerce' ) . '</a>';
			$links_array[] = '<a href=" https://docs.makewebbetter.com/mwb-multi-currency-switcher-for-woocommerce/" target="_blank"><img src="' . esc_html( MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_DIR_URL ) . 'admin/image/Documentation.svg" class="mwb-info-img" alt="documentation image">' . __( 'Documentation', 'mwb-multi-currency-switcher-for-woocommerce' ) . '</a>';
			$links_array[] = '<a href="https://support.makewebbetter.com/wordpress-plugins-knowledge-base/category/mwb-multi-currency-switcher-for-woocommerce/
			" target="_blank"><img src="' . esc_html( MWB_MULTI_CURRENCY_SWITCHER_FOR_WOOCOMMERCE_DIR_URL ) . 'admin/image/Support.svg" class="mwb-info-img" alt="support image">' . __( 'Support', 'mwb-multi-currency-switcher-for-woocommerce' ) . '</a>';
		}
		return $links_array;
	}
	add_filter( 'plugin_row_meta', 'mwb_multi_currency_switcher_for_woocommerce_custom_settings_at_plugin_tab', 10, 2 );

} else {


	// WooCommerce is not active so deactivate this plugin.
	add_action( 'admin_init', 'mwb_mmcsfw_currency_switcher_activation_failure' );

	/**
	 * This function is used to deactivate plugin.
	 *
	 * @name mwb_mmcsfw_currency_switcher_activation_failure
	 * @author makewebbetter<ticket@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function mwb_mmcsfw_currency_switcher_activation_failure() {

		deactivate_plugins( plugin_basename( __FILE__ ) );
	}

	// Add admin error notice.
	add_action( 'admin_notices', 'mwb_mmcsfw_currency_switcher_activation_failure_admin_notice' );

	/**
	 * This function is used to deactivate plugin.
	 *
	 * @name mwb_mmcsfw_currency_switcher_activation_failure_admin_notice
	 * @author makewebbetter<ticket@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	function mwb_mmcsfw_currency_switcher_activation_failure_admin_notice() {
			// hide Plugin activated notice.
		unset( $_GET['activate'] );
		if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			?>

			<div class="notice notice-error is-dismissible">
				<p><?php esc_html_e( 'WooCommerce is not activated, Please activate WooCommerce first to activate MWB Multi Currency Switcher for WooCommerce.', 'mwb-multi-currency-switcher-for-woocommerce' ); ?></p>
			</div>

			<?php
		}

	}
}
